% **********************************************
% *                                            *
% *         Class for TIK DASA                 *
% *                                            *
% **********************************************
%
% FILENAME:   TIKdasa.cls
%
% ABSTRACT:   Modifications to the 'article class' for
%             TIK diploma and semester theses. This class writes a
%             TIK-logo on the first page The page layout has
%             been adapted to A4 size. Language dependent strings will
%             be translated according to the chosen language. The groupname
%             can be specified with the \group macro
%             (in the <pers.>dat file).
%
% USAGE:      \documentclass[<lang.>]{TIKdasa}
%             \tikmember{<person>}
%
%             \begin{document}
%             \title{<title>}
%             \students{Herrn Adam Riese (IIIC)}
%             \dasatype{DIPLOMARBEIT}
%             \period{Wintersemester 1996/97}
%             \mainreader{Schamai Safra}
%             \alternatereader{Gunnar Lehtinen}
%             \issuedate{1. November 1996}
%             \submissiondate{28. Februar 1996}
%             \maketitle
% OPTIONAL:
%             \alternatereaderprefix{Co-Betreuer:}
%             etc.
%
% EXCEPTIONS: use above settings AFTER \begin{document} and BEFORE \maketitle
%
% HISTORY:    Written by Schamai Safra Jan 16, 1996.
%             Changed 1997/03/19 V0.92 (SchS):
%               put \tik@startbabelhack etc. to rehack new babel's hack of
%                   \ifthenelse (see tik.clo V0.91)
%               put \tik@dopostponed in the AtBeginDocument statement to
%                   do commands postponed until then (see tik.clo)
%               removed \maketitle from AtBeginDocument.
%             Changed 2002/22/01 V.093 (Thomas Duebendorfer)
%               new ETH logo
%             Changed 2003/06/17 V.094SA (Samuel Nobs)
%               supervisor on titlepage
%               normal textwidth
%************************************************************************
%
%\typeout{Document class for TIK DASA. Released 18 March 1997}
\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{TIKdasa}[2003/06/17 0.94sa (Samuel Nobs)]
\RequirePackage{ifthen}
\RequirePackage{t1enc}
%
% load definitions common to TIK documents  (prefixed \tik@ )
%
\input{tik.clo}
%
\input{tiklang.clo}
\input{TIKdasa.clo}
\newcommand{\tik@form}{ETHhdr}
\DeclareOption{TIKETH}{%
\renewcommand{\tik@form}{TIKETH}%
}
\DeclareOption{TIKhdr}{%
\renewcommand{\tik@form}{TIKhdr}%
}
\DeclareOption{ETHhdr}{%
\renewcommand{\tik@form}{ETHhdr}%
}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ExecuteOptions{E,TIKETH}
\ProcessOptions
\tik@startbabelhack
\RequirePackage[french, german, english]{babel}
\RequirePackage[\tik@form]{TIKform}
\LoadClass[a4paper]{book}
%provide commands normally defined in letter.cls
\tik@provide
\AtBeginDocument{%
  \input{tik.dat}%
  \input{TIKdasa.dat}%
  \tik@dopostponed%
  \tik@selectlanguage{\tik@lang}%
  \person@data%
%  \maketitle%
}%
\AtEndDocument{%
  \dateandsignature%
}%
%
%  fixed Fonts
%
\DeclareFixedFont{\xsl}{T1}{cmss}{m}{sl}{10}
\DeclareFixedFont{\xisl}{T1}{cmss}{m}{sl}{11}
%
% PAGE LAYOUT
%
%\setlength{\topmargin}{-10.4mm}
%\setlength{\headheight}{10mm}
%\setlength{\headsep}{5mm}
%\setlength{\textheight}{238mm}
%\setlength{\footskip}{13mm}
%\setlength{\oddsidemargin}{-.4mm}
%\setlength{\evensidemargin}{-.4mm}
%\setlength{\marginparwidth}{2.1cm}
%\setlength{\marginparsep}{10pt}
%\setlength{\textwidth}{16cm}
%
% MAKETITLE FOR DASA (by Josef Goette)
%
\def\maketitle{%\par
 \begingroup
   \def\thefootnote{\fnsymbol{footnote}}
   \def\@makefnmark{\hbox   
       to 0pt{$^{\@thefnmark}$\hss}}   
   \if@twocolumn               
     \twocolumn[\@maketitle]   
   \else 
     \newpage
     \global\@topnum\z@        % Prevents figures from going at top of page.
     \@maketitle 
   \fi\thispagestyle{TIKform}\@thanks
 \endgroup
 \setcounter{footnote}{0}
 \let\maketitle\relax
 \let\@maketitle\relax
 \gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}

\def\@maketitle{\newpage 
\hfill\groupstring\\ 
 \mbox{} \hfill
% \noindent{\small\groupstring}\\
 \null
 \vskip 1.5em                 % Vertical space above title.
 \begin{flushright}
    \large
    \periodstring
 \end{flushright}
 \vskip 1.5em
 \begin{center}
    \Large \dasatypestring\\[0.2cm]
    \large \forstring\\[0.2cm]
    \Large \studentstring%
 \end{center}%
 \vskip 1.5em
 \begin{center}
    \large
    \begin{tabular}{ll}
       Tutors:      & \mainreaderstring
       \ifx\@empty\alternatereaderstring
       \\
       \else 
         \\
         & \alternatereaderstring
       \fi 
       \ifx\@empty\professorstring
       \\
       \else
       \\
       Supervisors: & \professorstring \hspace{8pt} and \\
 & Prof.~Dr.~L. Thiele 
       \fi
    \end{tabular}
 \end{center}
 \vskip 0.5em
 \hrule height0.3pt
 \begin{center}
    \large
    \begin{tabular}{ll}
       \issuedateprefixstring      & \issuedatestring \\
       \submissiondateprefixstring & \submissiondatestring
    \end{tabular}
 \end{center}
 \hrule height0.3pt
 \vskip 2.5em
 \begin{center}
    \Huge
    \titlestring
 \end{center}
 \vskip 1em
 \hrule height 0.3pt
 \par
 \vskip 2.5em
}
%
% DATE AND SIGNATURE (by Heinz Kindlimann (mod. Schamai Safra))
%
\newcommand{\dateandsignature}{
  \vspace{2.5cm plus0pt minus2cm}
    \noindent
    \parbox{\textwidth}{
      \dateprefixstring\ \@date \hfill
      \professorstring
    }
}
%
%  PAGE STYLE
%
\def\@texttop{}
